@@ -197,7 +197,7 @@ def _gen_path_list(file_obj):
         `file_obj` {str|list|dict}
             The object to parse for file_paths.
 
-            It can be a single path, list of paths, list of file objects, or a single file object. 
+            It can be a single path, list of paths, list of file objects, or a single file object.
 
         Return {list}
         ----------------------
@@ -369,10 +369,18 @@ def copy(src, dest=False, **kwargs):
     # print(f"copy_list: {copy_list}")
 
 
-def _copy_files_from_array(file_list):
+def _copy_files_from_array(file_list, attempted_delete=False):
     for file in file_list:
-        os.makedirs(os.path.dirname(file['dst_path']), exist_ok=True)
-        shutil.copy2(file['src_path'], file['dst_path'])
+        try:
+            os.makedirs(os.path.dirname(file['dst_path']), exist_ok=True)
+            shutil.copy2(file['src_path'], file['dst_path'])
+        except PermissionError as error:
+            if attempted_delete is False:
+                _delete_single_file(file['dst_path'])
+                _copy_files_from_array([file], True)
+            else:
+                print(f"Failed to copy file: {file['src_path']} to {file['dst_path']}.\n{error}")
+                print(traceback.format_exc())
     return True
 
 
@@ -481,9 +489,32 @@ def _thread_file_action(file_list, **kwargs):
         thread.start()
     for thread in threads:
         thread.join()
+
     return
 
 
+# def get_modtime_size(file_path, **kwargs):
+#     data_include = obj.get_kwarg(['include', "data include"], [], (list, str), **kwargs)
+#     if isinstance(data_include, (str)):
+#         data_include = [data_include]
+#     file_path = strUtils.format.file_path(file_path)
+#     if exists(file_path):
+#         # print(f"file exists: {file_path}")
+#         # print(f"Getting data for file: {file_path}")
+#         try:
+#             file_data = {}
+#             file_data['file_path'] = file_path
+#             file_data['modified_time'] = get_modified_time(file_path)
+#             file_data['size'] = os.path.getsize(file_path)
+
+#             return file_data
+#         except FileNotFoundError as error:
+#             logger.warning(f"Error: {error}")
+#             return None
+#     else:
+#         logger.warning(f"Failed to find the file: {file_path}")
+
+
 def get_data(file_path, **kwargs):
     '''
         Get data associated to the file_path provided.
@@ -516,28 +547,34 @@ def get_data(file_path, **kwargs):
         `method_name`: get_data
     '''
 
-    exclude = obj.get_kwarg(['exclude'], [], (list, str), **kwargs)
+    data_include = obj.get_kwarg(['include', "data include"], [], (list, str), **kwargs)
+    if isinstance(data_include, (str)):
+        data_include = [data_include]
+    if len(data_include) == 0:
+        data_include = ['file_name', 'extension', 'name_no_ext', 'dir_path', 'access_time', 'modified_time', 'created_time', 'size']
     file_path = strUtils.format.file_path(file_path)
     if exists(file_path):
         # print(f"file exists: {file_path}")
         # print(f"Getting data for file: {file_path}")
         try:
             file_data = {}
-            file_data['file_name'] = os.path.basename(file_path)
-            # ext = os.path.splitext(file_data['file_name'])
-            file_data['extension'] = get_ext(file_path)
-            file_data['name_no_ext'] = get_name_no_ext(file_path)
             file_data['file_path'] = file_path
 
-            if 'dir_path' not in exclude:
+            if 'file_name' in data_include:
+                file_data['file_name'] = os.path.basename(file_path)
+            if 'extension' in data_include:
+                file_data['extension'] = get_ext(file_path)
+            if 'name_no_ext' in data_include:
+                file_data['name_no_ext'] = get_name_no_ext(file_path)
+            if 'dir_path' in data_include:
                 file_data['dir_path'] = os.path.dirname(file_path)
-            if 'access_time' not in exclude:
+            if 'access_time' in data_include:
                 file_data['access_time'] = get_access_time(file_path)
-            if 'modified_time' not in exclude:
+            if 'modified_time' in data_include:
                 file_data['modified_time'] = get_modified_time(file_path)
-            if 'created_time' not in exclude:
+            if 'created_time' in data_include:
                 file_data['created_time'] = get_create_time(file_path)
-            if 'size' not in exclude:
+            if 'size' in data_include:
                 file_data['size'] = os.path.getsize(file_path)
 
             return file_data
@@ -693,3 +730,8 @@ def get_name_no_ext(file_path):
 # print(exists(clean))
 # file = strUtils.format.file_path(file)
 # get_data(file)
+
+
+# src = r"Z:\Structure\Archive\Images\Personal\Other\desktop.ini"
+# dst = r"X:\Structure\Archive\Images\Personal\Other\desktop.ini"
+# _copy_files_from_array([{"src_path": src, "dst_path": dst}])
